@@ -4,8 +4,6 @@ import IPython
 DatosList = []
 Orden = 8
 
-#Funciones para economizar tiempo
-
 #Funciones de Redondeo
 def Redondear(expr):#Redondeamos la expresión.
   if isinstance(expr, sy.Expr) or isinstance(expr, sy.Float):
@@ -59,11 +57,11 @@ def E(expr,color = "red"):
 
   if isinstance(expr,sy.core.relational.Equality):
     D(expr.subs(DataRealSymbolList))
-    D(sy.N(expr.subs(DatosList)))
+    #D(sy.N(expr.subs(DatosList)))
   
   if isinstance(expr,list):
     D([expr[0],expr[1].subs(DataRealSymbolList)])
-    D([expr[0],sy.N(expr[1].subs(DatosList))])
+    #D([expr[0],sy.N(expr[1].subs(DatosList))])
 
 def G(c_componente):#Guardar
   dentro = False
